@@ -6,6 +6,7 @@ function :func:`get_test_path`.
 """
 import os
 import logging
+from copy import copy
 from pathlib import Path
 from typing import (Optional, Callable, Tuple, Any, Dict, List, Union)
 import itertools as it
@@ -645,8 +646,9 @@ class CallableTest:
             )
 
     # pylint: disable=too-many-branches
+    @classmethod
     def _unroll_kwargs_dict(
-            self, kwargs: Dict[str, Any]) -> List[Dict[str, Any]]:
+            cls, kwargs: Dict[str, Any]) -> List[Dict[str, Any]]:
         """Unroll kwargs dict into the list of all possible kwargs.
 
         Args:
@@ -660,7 +662,7 @@ class CallableTest:
         """
         kwargs_list = list()
         for arg_name, arg_value in kwargs.items():
-            value_list = self._get_extended_value_list(arg_value)
+            value_list = cls._get_extended_value_list(arg_value)
 
             if not kwargs_list:
                 # Handling the first argument
@@ -673,12 +675,12 @@ class CallableTest:
                 new_kwargs_list = list()
                 for kwa in kwargs_list:
                     for value in value_list:
-                        new_kwargs = kwa
+                        new_kwargs = copy(kwa)
                         new_kwargs[arg_name] = value
                         new_kwargs_list.append(new_kwargs)
                 kwargs_list = new_kwargs_list
 
-        self._remove_optional_args(kwargs_list)
+        cls._remove_optional_args(kwargs_list)
         return kwargs_list
 
     @classmethod
